@@ -144,7 +144,7 @@ static void test_task_transition(void)
 	set(policy);
 	check_init(policy, "<init3>");
 	unset(policy);
-	
+
 	policy = "100 acl auto_domain_transition\n"
 		"0 allow task.pid=1 transition=\"<init>\"\n";
 	set(policy);
@@ -165,7 +165,7 @@ static void test_file_read(void)
 	check(policy, fd != EOF);
 	close(fd);
 	unset(policy);
-	
+
 	policy = "100 acl read\n"
 		"0 allow\n"
 		"1 deny\n";
@@ -174,7 +174,7 @@ static void test_file_read(void)
 	check(policy, fd != EOF);
 	close(fd);
 	unset(policy);
-	
+
 	policy = "100 acl read\n"
 		"0 deny\n"
 		"1 allow\n";
@@ -183,7 +183,7 @@ static void test_file_read(void)
 	check(policy, fd == EOF);
 	close(fd);
 	unset(policy);
-	
+
 	policy = "100 acl read path=\"/dev/null\"\n"
 		"0 allow\n"
 		"1 deny\n";
@@ -465,9 +465,9 @@ static void test_file_create(void)
 	unset(policy);
 
 	policy = "100 acl create\n"
-		"0 allow path=\"dev(¥$,¥$):/tmp/file\" path.parent.uid=0\n"
+		"0 allow path=\"dev(\\$,\\$):/tmp/file\" path.parent.uid=0\n"
 		"0 allow path=\"/tmp/file\" path.parent.uid=0\n"
-		"0 allow path=\"dev(¥$,¥$):/file\" path.parent.uid=0\n"
+		"0 allow path=\"dev(\\$,\\$):/file\" path.parent.uid=0\n"
 		"1 deny\n";
 	set(policy);
 	unlink("/tmp/file");
@@ -543,7 +543,7 @@ static void test_file_link(void)
 	unlink("/tmp/file2");
 	check(policy, link("/tmp/file", "/tmp/file2") == 0);
 	unset(policy);
-	
+
 	policy = "100 acl link\n"
 		"0 deny old_path.uid=0 old_path.uid=old_path.parent.uid\n"
 		"1 allow\n";
@@ -567,7 +567,7 @@ static void test_file_rename(void)
 	unlink("/tmp/file2");
 	check(policy, rename("/tmp/file", "/tmp/file2") == 0);
 	unset(policy);
-	
+
 	policy = "100 acl rename\n"
 		"0 deny old_path.uid=0 old_path.uid=old_path.parent.uid\n"
 		"1 allow\n";
@@ -602,7 +602,7 @@ static void test_network_inet_stream(void)
 	check(policy, bind(fd1, (struct sockaddr *) &addr1, sizeof(addr1)) ==
 	      EOF);
 	unset(policy);
-	
+
 	policy = "100 acl inet_stream_bind\n"
 		"0 allow ip!=127.0.0.1 port=0\n"
 		"1 deny\n";
@@ -618,7 +618,7 @@ static void test_network_inet_stream(void)
 	check(policy, bind(fd1, (struct sockaddr *) &addr1, sizeof(addr1)) ==
 	      EOF);
 	unset(policy);
-	
+
 	policy = "100 acl inet_stream_bind\n"
 		"0 allow ip=127.0.0.1 port=0\n"
 		"1 deny\n";
@@ -732,7 +732,7 @@ static void test_network_inet_dgram(void)
 	check(policy, bind(fd1, (struct sockaddr *) &addr1, sizeof(addr1)) ==
 	      EOF);
 	unset(policy);
-	
+
 	policy = "100 acl inet_dgram_bind\n"
 		"0 allow ip!=127.0.0.1 port=0\n"
 		"1 deny\n";
@@ -816,7 +816,7 @@ static void test_network_inet_dgram(void)
 static void test_network_inet_raw(void)
 {
 	struct sockaddr_in addr = { };
-	static struct iphdr ip = { };
+	struct iphdr ip = { };
 	int fd1;
 	int fd2;
 	char *policy;
@@ -886,7 +886,7 @@ static void test_network_inet_raw(void)
 	unset(policy);
 
 	policy = "100 acl inet_raw_send\n"
-		 "0 allow ip=127.0.0.1 proto=1\n"
+		"0 allow ip=127.0.0.1 proto=1\n"
 		"1 deny\n";
 	set(policy);
 	check(policy, send(fd2, &ip, sizeof(ip), 0) != EOF);
@@ -917,6 +917,8 @@ static void test_network_inet6_stream(void)
 	memset(buffer, 0, sizeof(buffer));
 
 	fd1 = socket(PF_INET6, SOCK_STREAM, 0);
+	if (fd1 == EOF && errno == EAFNOSUPPORT)
+		return;
 	fd2 = socket(PF_INET6, SOCK_STREAM, 0);
 	addr1.sin6_family = AF_INET6;
 	addr1.sin6_addr = in6addr_loopback;
@@ -1047,6 +1049,8 @@ static void test_network_inet6_dgram(void)
 	memset(buffer, 0, sizeof(buffer));
 
 	fd1 = socket(PF_INET6, SOCK_DGRAM, 0);
+	if (fd1 == EOF && errno == EAFNOSUPPORT)
+		return;
 	fd2 = socket(PF_INET6, SOCK_DGRAM, 0);
 	addr1.sin6_family = AF_INET6;
 	addr1.sin6_addr = in6addr_loopback;
